@@ -323,7 +323,7 @@ def parse_column_data(value=None):
 
 def parse_schema_statement(value=None):
     # TODO []: remove this!!! it is for testing only!!!!!
-    value = "CREATE SCHEMA IF NOT EXISTS `idealech_Equari_Content_Database`;"
+    # value = "CREATE SCHEMA IF NOT EXISTS `idealech_Equari_Content_Database`;"
 
 
     _tick,_double_quote,_single_quote,_period = [Suppress(x) for x in list('`"\'.')]
@@ -422,6 +422,7 @@ def parse_table_statement(value=None):
             new_data["constraints"] = d['constraints']
         # print(new_data)
         output = new_data
+        
     return output
 
 def _parse_table_column_lines(lines):
@@ -451,6 +452,10 @@ def _parse_table_column_lines(lines):
 
         # parse_column_data(line)
     # data['keys'] = keys
+    for c in data['columns']:
+        c['is_primary_key'] = False
+        if c['name'] in data['primary_keys']:
+            c['primary_key'] = True
     return data
 
 def capture_create_table_columns(sql):
