@@ -20,7 +20,7 @@
 # import utils.objectUtils as objUtils
 import logging
 import utils.objectUtils as obj
-import utils.sql_facade as sql
+import facades.sql_parse_facade as sql
 logger = logging.getLogger(__name__)
 
 
